#!/bin/bash

## Check for a valid mode selection (durable or reliable)
case "$1" in
  -d|--durable)
    mode="durable"
    ;; 
  -r|--reliable)
    mode="reliable"
    ;; 
  -q|--queue)
    mode="queue"
    ;; 
*)
  echo $"Usage $0 [-d|--durable|-r|--reliable|-q|--queue]"
  exit 1
esac

if [ -z $MULE_HOME ]; then
  if [ -d ../mule-1.4.3 ]; then
    curdir=`pwd`
    parentdir=`dirname $curdir`
    MULE_HOME=$parentdir/mule-1.4.3
    export MULE_HOME
  fi
fi

if [ ! -d $MULE_HOME ]; then
  echo "MULE_HOME must be set to the Mule Home Directory before running this program.  Exiting."
  exit 1
fi

#
# Set the classpath

JMS_JAR=$MULE_HOME/lib/user/jms.jar
if [ ! -f $JMS_JAR ]; then
  echo "jms.jar must be copied to $JMS_JAR before running this program.  Exiting."
  exit 1
fi

CLIENT_JAR=`ls $MULE_HOME/lib/user/ambrosia-client-*.jar`
if [ ! -f $CLIENT_JAR ]; then
  echo "The Ambrosia client jar (ambrosia-client-.jar) must be copied to $MULE_HOME/lib/user/ before running this program.  Exiting."
  exit 1
fi

export CLASSPATH=.:./bin:$JMS_JAR:$CLIENT_JAR:$CLASSPATH

#echo "Compiling the AmbMule example from the example package"
#javac AmbMule.java

opts=

echo
echo "Run the AmbMule example Ambrosia JMS client, with mode: $mode"


if [ "$mode" = "durable" ]; then
  java $opts AmbMule --${mode} "localhost:8021, localhost:8011" Administrator Administrator pool-2
fi

if [ "$mode" = "reliable" ]; then
  java $opts AmbMule --${mode} "localhost:8021, localhost:8011" Administrator Administrator
fi

if [ "$mode" = "queue" ]; then
  uidpwd=MT1
  echo "  INFO: Setting the user id to use for Queues to: $uidpwd"
  export uid=$uidpwd
  export password=$uidpwd
  java $opts AmbMule --${mode} "localhost:8021, localhost:8011" Administrator Administrator
fi

